emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 55f3f21 1/2: * lisp/net/tramp.el (tramp-get-local-g


From: Michael Albinus
Subject: [Emacs-diffs] master 55f3f21 1/2: * lisp/net/tramp.el (tramp-get-local-gid): Use `group-name' if available.
Date: Sat, 10 Nov 2018 10:03:24 -0500 (EST)

branch: master
commit 55f3f21b39389263d707b091d7e1b45d295a149c
Author: Michael Albinus <address@hidden>
Commit: Michael Albinus <address@hidden>

    * lisp/net/tramp.el (tramp-get-local-gid): Use `group-name' if available.
---
 lisp/net/tramp.el | 12 ++++++++----
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 4ee69d7..44d6640 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -4193,10 +4193,14 @@ ID-FORMAT valid values are `string' and `integer'."
 (defun tramp-get-local-gid (id-format)
   "The gid of the local user, in ID-FORMAT.
 ID-FORMAT valid values are `string' and `integer'."
-  ;; `group-gid' has been introduced with Emacs 24.4.
-  (if (and (fboundp 'group-gid) (equal id-format 'integer))
-      (tramp-compat-funcall 'group-gid)
-    (tramp-compat-file-attribute-group-id (file-attributes "~/" id-format))))
+  (cond
+   ;; `group-gid' has been introduced with Emacs 24.4.
+   ((and (fboundp 'group-gid) (equal id-format 'integer))
+    (tramp-compat-funcall 'group-gid))
+   ;; `group-name' has been introduced with Emacs 27.1.
+   ((and (fboundp 'group-name) (equal id-format 'string))
+    (tramp-compat-funcall 'group-name (tramp-compat-funcall 'group-gid)))
+   ((tramp-compat-file-attribute-group-id (file-attributes "~/" id-format)))))
 
 (defun tramp-get-local-locale (&optional vec)
   "Determine locale, supporting UTF8 if possible.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]